#!/usr/bin/env python3
# -*- coding: utf-8, vim: expandtab:ts=4 -*-

"""
sono - a sound and music toolkit
Copyright (C) 2021  András Németh

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

# imports: library
from argparse import ArgumentParser
import configparser
import logging
import logging.config
import pkg_resources
import sys
import tkinter  # no underscore, lowercase 't' for V3.0 and later
from tkinter import ttk

# imports: project
from sono.version import __version__


def main() -> None:

    logger_config_name = 'data/logger.ini'

    if not pkg_resources.resource_exists(__name__, logger_config_name):
        logging.error('logger config does not exist')
        return

    logger_config = pkg_resources.resource_stream(__name__, logger_config_name)
    logger_config_str = logger_config.read().decode('UTF-8')
    logger_config_parser = configparser.ConfigParser()
    logger_config_parser.read_string(logger_config_str)
    logging.config.fileConfig(logger_config_parser)

    logging.info('Sono')
    logging.info('----')

    parser = ArgumentParser(prog='sono')

    parser.add_argument('--version',
                        help='Display version',
                        action='store_const', const=True, default=False,
                        dest='version')

    args = parser.parse_args(sys.argv[1:])

    if args.version:
        print(f'Sono {__version__}')
        return

    root = tkinter.Tk()
    frm = ttk.Frame(root, padding=10)
    frm.grid()

    ttk.Label(frm,
              text='Sono'
              ).grid(column=0,
                     row=0)

    ttk.Button(frm,
               text="Quit",
               command=root.destroy
               ).grid(column=0,
                      row=1)

    root.mainloop()


if __name__ == '__main__':
    main()
